@@ -18,7 +18,7 @@ fn main() {
 struct FontIndex(pub usize);
 
 fn spawn_terminal(mut commands: Commands, fonts: Res<BuiltInFontHandles>) {
-    let size = [47, 12];
+    let size = [47, 13];
     let mut term_bundle = TerminalBundle::new().with_size(size);
 
     term_bundle.terminal.draw_border_single();
@@ -27,19 +27,26 @@ fn spawn_terminal(mut commands: Commands, fonts: Res<BuiltInFontHandles>) {
 
     draw_title(&mut term_bundle.terminal, fonts[0].0);
 
+    let format = Pivot::TopLeft.into();
     term_bundle
         .terminal
-        .put_string([1, 2], "Press spacebar to change fonts");
+        .put_string_formatted([1, 2], "Press spacebar to change fonts", format);
     term_bundle.terminal.put_string([1, 4], "!@#$%^&*()_+=-`~");
-    term_bundle
-        .terminal
-        .put_string([1, 6], "The quick brown fox jumps over the lazy dog.");
-    term_bundle
-        .terminal
-        .put_string([1, 8], "☺☻♥♦♣♠•'◘'○'◙'♂♀♪♫☼►◄↕‼¶§▬↨↑↓→←∟↔▲▼");
-    term_bundle
-        .terminal
-        .put_string([1, 10], "░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞");
+    term_bundle.terminal.put_string_formatted(
+        [1, 6],
+        "The quick brown fox jumps over the lazy dog.",
+        format,
+    );
+    term_bundle.terminal.put_string_formatted(
+        [1, 8],
+        "☺☻♥♦♣♠•'◘'○'◙'♂♀♪♫☼►◄↕‼¶§▬↨↑↓→←∟↔▲▼",
+        format,
+    );
+    term_bundle.terminal.put_string_formatted(
+        [1, 10],
+        "░▒▓│┤╡╢╖╕╣║╗╝╜╛┐└╒╓╫╪┘┌█▄▌▐▀αßΓπΣσµτΦΘΩδ∞",
+        format,
+    );
     commands.spawn_bundle(term_bundle);
 
     commands.spawn_bundle(
@@ -52,15 +59,14 @@ fn spawn_terminal(mut commands: Commands, fonts: Res<BuiltInFontHandles>) {
 fn draw_title(term: &mut Terminal, title: &str) {
     let title = &title[0..title.len() - 4];
 
-    term.draw_border_single_color(WHITE, BLACK);
-    term.put_string([1, 0], "[ ");
-    term.put_string_color(
+    term.draw_border_single();
+    term.put_string_formatted([1, 0], "[ ", Pivot::TopLeft.into());
+    term.put_string_formatted(
         [3, 0],
         title.to_string().to_uppercase().as_str(),
-        BLUE,
-        BLACK,
+        StringFormat::new(Pivot::TopLeft, Color::BLUE, Color::BLACK),
     );
-    term.put_string([4 + title.len() as i32 - 1, 0], " ]");
+    term.put_string_formatted([4 + title.len() as i32 - 1, 0], " ]", Pivot::TopLeft.into());
 }
 
 fn change_font(
