@@ -13,8 +13,8 @@ fn main() {
         .add_plugin(TerminalPlugin)
         .add_plugin(TiledCameraPlugin)
         .insert_resource(ClearColor(Color::BLACK))
-        .add_startup_system(setup.system())
-        .add_system(change_font.system())
+        .add_startup_system(setup)
+        .add_system(change_font)
         .run()
 }
 
